@@ -1,5 +1,8 @@
 /* RISCOS/pyconfig.h: Python configuration for RISC OS  */
 
+#ifndef Py_PYCONFIG_H
+#define Py_PYCONFIG_H
+
 /* Define if on AIX 3.
    System headers sometimes define this.
    We just want to avoid a redefinition error message.  */
@@ -25,9 +28,6 @@
    tzname.  */
 #undef HAVE_TZNAME
 
-/* Define if on MINIX.  */
-#undef _MINIX
-
 /* Define to `int' if <sys/types.h> doesn't define.  */
 #undef mode_t
 
@@ -70,10 +70,6 @@
    and you want support for AIX C++ shared extension modules. */
 #undef AIX_GENUINE_CPLUSPLUS
 
-/* Define if your <unistd.h> contains bad prototypes for exec*()
-   (as it does on SGI IRIX 4.x) */
-#undef BAD_EXEC_PROTOTYPES
-
 /* Define if your compiler botches static forward declarations
    (as it does on SCI ODT 3.0) */
 #undef BAD_STATIC_FORWARD
@@ -143,7 +139,7 @@
 #undef HAVE_LARGEFILE_SUPPORT
 
 /* Define this if you have the type long long */
-#undef HAVE_LONG_LONG
+#define HAVE_LONG_LONG
 
 /* Define if your compiler supports function prototypes */
 #define HAVE_PROTOTYPES 1
@@ -184,9 +180,6 @@
 /* Define if nice() returns success/failure instead of the new priority. */
 #undef HAVE_BROKEN_NICE
 
-/* Define if malloc(0) returns a NULL pointer */
-#undef MALLOC_ZERO_RETURNS_NULL
-
 /* Define if you have POSIX threads */
 #undef _POSIX_THREADS
 
@@ -236,19 +229,8 @@
    one supplied by Python itself. (see Include/unicodectype.h). */
 #undef WANT_WCTYPE_FUNCTIONS
 
-/* Define if you want to compile in cycle garbage collection */
-#define WITH_CYCLE_GC 1
-
-/* Define if you want to emulate SGI (IRIX 4) dynamic linking.
-   This is rumoured to work on VAX (Ultrix), Sun3 (SunOS 3.4),
-   Sequent Symmetry (Dynix), and Atari ST.
-   This requires the "dl-dld" library,
-   ftp://ftp.cwi.nl/pub/dynload/dl-dld-1.1.tar.Z,
-   as well as the "GNU dld" library,
-   ftp://ftp.cwi.nl/pub/dynload/dld-3.2.3.tar.Z.
-   Don't bother on SunOS 4 or 5, they already have dynamic linking using
-   shared libraries */ 
-#undef WITH_DL_DLD
+/* Define if you want documentation strings in extension modules */
+#define WITH_DOC_STRINGS 1
 
 /* Define if you want to use the new-style (Openstep, Rhapsody, MacOS)
    dynamic linker (dyld) instead of the old-style (NextStep) dynamic
@@ -256,7 +238,7 @@
 #undef WITH_DYLD
 
 /* Define if you want to compile in Python-specific mallocs */
-#undef WITH_PYMALLOC
+#define WITH_PYMALLOC 1
 
 /* Define if you want to produce an OpenStep/Rhapsody framework
    (shared library plus accessory files). */
@@ -265,13 +247,6 @@
 /* Define if you want to use MacPython modules on MacOSX in unix-Python */
 #undef USE_TOOLBOX_OBJECT_GLUE
 
-/* Define if you want to use SGI (IRIX 4) dynamic linking.
-   This requires the "dl" library by Jack Jansen,
-   ftp://ftp.cwi.nl/pub/dynload/dl-1.6.tar.Z.
-   Don't bother on IRIX 5, it already has dynamic linking using SunOS
-   style shared libraries */ 
-#undef WITH_SGI_DL
-
 /* Define if you want to compile in rudimentary thread support */
 #undef WITH_THREAD
 
@@ -294,7 +269,7 @@
 #define SIZEOF_LONG 4
 
 /* The number of bytes in a long long.  */
-#undef SIZEOF_LONG_LONG
+#define SIZEOF_LONG_LONG 8
 
 /* The number of bytes in a short.  */
 #define SIZEOF_SHORT 2
@@ -399,7 +374,10 @@
 #undef HAVE_GETNAMEINFO
 
 /* Define if you have the getpeername function.  */
-#undef HAVE_GETPEERNAME
+#define HAVE_GETPEERNAME
+
+/* Define if you have the getpgid function.  */
+#undef HAVE_GETPGID
 
 /* Define if you have the getpgrp function.  */
 #undef HAVE_GETPGRP
@@ -423,7 +401,7 @@
 #undef HAVE_HSTRERROR
 
 /* Define if you have the hypot function.  */
-#undef HAVE_HYPOT
+#define HAVE_HYPOT
 
 /* Define if you have the inet_pton function.  */
 #define HAVE_INET_PTON 1
@@ -536,9 +514,6 @@
 /* Define if you have the strftime function.  */
 #define HAVE_STRFTIME 1
 
-/* Define if you have the strptime function.  */
-#undef HAVE_STRPTIME
-
 /* Define if you have the symlink function.  */
 #undef HAVE_SYMLINK
 
@@ -605,12 +580,6 @@
 /* Define if you have the <libutil.h> header file.  */
 #undef HAVE_LIBUTIL_H
 
-/* Define if you have the <limits.h> header file.  */
-#define HAVE_LIMITS_H 1
-
-/* Define if you have the <locale.h> header file.  */
-#define HAVE_LOCALE_H 1
-
 /* Define if you have the <ncurses.h> header file.  */
 #undef HAVE_NCURSES_H
 
@@ -632,18 +601,6 @@
 /* Define if you have the <pty.h> header file.  */
 #undef HAVE_PTY_H
 
-/* Define if you have the <signal.h> header file.  */
-#define HAVE_SIGNAL_H 1
-
-/* Define if you have the <stdarg.h> header file.  */
-#define HAVE_STDARG_H 1
-
-/* Define if you have the <stddef.h> header file.  */
-#define HAVE_STDDEF_H 1
-
-/* Define if you have the <stdlib.h> header file.  */
-#define HAVE_STDLIB_H 1
-
 /* Define if you have the <sys/audioio.h> header file.  */
 #undef HAVE_SYS_AUDIOIO_H
 
@@ -734,3 +691,5 @@
 #undef DONT_HAVE_SYS_STAT_H
 
 #define PLATFORM "riscos"
+
+#endif /* Py_PYCONFIG_H */
